@@ -1,11 +1,13 @@
 <?php
 $opaqueLogo = get_template_directory_uri() . '/dist/images/opaque-logo.png';
+$greenBg = get_template_directory_uri() . '/dist/images/green-pattern.jpg';
+$pageForPosts = get_option( 'page_for_posts' );
 ?>
 
 <div class="custom-archive">
-    <div class="banner">
+    <div class="banner" style="background-image:url('<?= $greenBg; ?>')">
         <div class="container">
-            <h1>News</h1>
+            <h1><?= get_the_title($pageForPosts); ?></h1>
         </div>
     </div>
     <div class="container archive-container" style="background-image:url(<?= $opaqueLogo; ?>)">
@@ -26,5 +28,5 @@ $opaqueLogo = get_template_directory_uri() . '/dist/images/opaque-logo.png';
     </div>
 </div>
 <div class="flexible-layout-sections">
-    <?php Blue2\Scruffy\Utils::flexibleLoop('flexible_sections'); ?>
+    <?php Blue2\Scruffy\Utils::flexibleLoop('flexible_sections', $pageForPosts); ?>
 </div>
